Support for Traja
=================

Bugs
----

Bugs, issues and improvement requests can be logged in `Github Issues <https://github.com/traja-team/traja/issues>`_. 

Community
---------

Community support is provided via `Gitter <https://gitter.im/traja-chat/community>`_. Just ask a question there.
